package com.elitesland.user.controller;

import com.elitesland.core.base.ApiCode;
import com.elitesland.core.base.ApiResult;
import com.elitesland.core.exception.BusinessException;
import com.elitesland.core.util.RedisUtils;
import com.elitesland.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import java.util.HashMap;

/**
 * @Author Kevin.yuan
 * @Data 2021/2/8 14:01
 * @description
 */
@RestController
@RequestMapping("/carUser")
@RequiredArgsConstructor
@Slf4j
@Api(value = "获取车主及车辆信息", tags = {"获取车主及车辆信息"})
public class CarInformationController {

    private final RedisUtils redisUtils;

    @Value("${carUser.tokenUrl}")
    private String tokenUrl;

    @Value("${carUser.username}")
    private String username;

    @Value("${carUser.password}")
    private String password;

    @Value("${carUser.getSaleVoucherByVinUrl}")
    private String getSaleVoucherByVinUrl;

    @Value("${carUser.getSaleVoucherByPhone}")
    private String getSaleVoucherByPhone;




    @GetMapping("/getSaleVoucherByVin")
    @ApiOperation("根据车架号获取车辆信息")
    public ApiResult<String> queue(String vinNumber) {
        //获取token
        RestTemplate restTemplate = new RestTemplate();
        String acessToken = TokenUtil.vorifyToke(username,password,tokenUrl,redisUtils);
        //设置请求参数
        HashMap<String, String> hashMap = new HashMap<>();
        hashMap.put("vinNumber",vinNumber);
        HttpHeaders headers = new HttpHeaders();
        log.info(acessToken);
        headers.add("Authorization", "Bearer "+acessToken);
        HttpEntity<MultiValueMap<String, String>> httpEntity = new HttpEntity<>(null,headers);
        //发起请求
        ResponseEntity<String> exchange = restTemplate.exchange(getSaleVoucherByVinUrl+"?vinNumber={vinNumber}", HttpMethod.GET, httpEntity, String.class,hashMap);
        if (exchange.getStatusCode().compareTo(HttpStatus.OK) != 0) {
            throw new BusinessException(ApiCode.FAIL, "接口异常，请稍后重试");
        }
        return ApiResult.ok(exchange.getBody());
    }

    @GetMapping("/getSaleVoucherByPhone")
    @ApiOperation("根据手机号查询车主信息")
    public ApiResult<String> getSaleVoucherByPhone(String phone) {
        //获取token
        RestTemplate restTemplate = new RestTemplate();
        String acessToken = TokenUtil.vorifyToke(username,password,tokenUrl,redisUtils);
        //设置请求参数
        HashMap<String, String> hashMap = new HashMap<>();
        hashMap.put("phone",phone);
        HttpHeaders headers = new HttpHeaders();
        log.info(acessToken);
        headers.add("Authorization", "Bearer "+acessToken);
        HttpEntity<MultiValueMap<String, String>> httpEntity = new HttpEntity<>(null,headers);
        //发起请求
        ResponseEntity<String> exchange = restTemplate.exchange(getSaleVoucherByPhone+"?phone={phone}", HttpMethod.GET, httpEntity, String.class,hashMap);
        if (exchange.getStatusCode().compareTo(HttpStatus.OK) != 0) {
            throw new BusinessException(ApiCode.FAIL, "接口异常，请稍后重试");
        }
        return ApiResult.ok(exchange.getBody());
    }
}
