package com.elitesland.utils;

import com.alibaba.fastjson.JSONObject;
import com.elitesland.core.base.ApiCode;
import com.elitesland.core.base.ApiResult;
import com.elitesland.core.exception.BusinessException;
import com.elitesland.core.util.RedisUtils;
import org.springframework.http.*;
import org.springframework.util.StringUtils;
import org.springframework.web.client.RestTemplate;

import java.util.Base64;

/**
 * @Author Kevin.yuan
 * @Data 2021/2/8 15:47
 * @description
 */
public class TokenUtil {
    public static String vorifyToke(String userName, String password, String url, RedisUtils redisUtils){
        String token= (String) redisUtils.get(userName);
        //验证token是否已经存在
        if (StringUtils.isEmpty(token)) {
            RestTemplate restTemplate = new RestTemplate();
            //在请求头信息中携带Basic认证信息(这里才是实际Basic认证传递用户名密码的方式)
            HttpHeaders headers = new HttpHeaders();
            headers.set("authorization",
                    "Basic " +
                            Base64.getEncoder()
                                    .encodeToString((userName + ":" + password).getBytes()));

            //发送请求
            ResponseEntity<String> result = restTemplate
                    .exchange(url,
                            HttpMethod.POST,   //GET请求
                            new HttpEntity<>(null, headers),   //加入headers
                            String.class);//body响应数据接收类型
            if (result.getStatusCode().compareTo(HttpStatus.OK) != 0) {
                throw new BusinessException(ApiCode.FAIL, "接口异常，请稍后重试");
            }
            JSONObject jsonObject = JSONObject.parseObject(result.getBody());
            Object access_token = jsonObject.get("access_token");
            Object expires_in = jsonObject.get("expires_in");

            redisUtils.set(userName, access_token, Long.parseLong(expires_in + "") - 20L);
//            RestTemplateBuilder b = new RestTemplateBuilder();
//            RestTemplate rest = b.basicAuthentication("calling", "ev14sHOKUmUdiQ1d").build();
//            ResponseEntity<String> result = rest.exchange("https://tdev.yadea.com.cn:6061/dapi-uaa/oauth/token?grant_type=client_credentials&scope=calling", HttpMethod.POST, new HttpEntity<>(null, null), String.class);

            return (String) access_token;
        }
        return token;
    }
}
